%define upstream_name    Test-Signature
%define upstream_version 1.11

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:           perl-%{upstream_name}
Version:        %perl_convert_version %{upstream_version}
Release:        %mkrel 10
Summary:        Automated SIGNATURE testing
License:        GPL+ or Artistic
Group:          Development/C
URL:            https://metacpan.org/release/%{upstream_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AU/AUDREYT/%{upstream_name}-%{upstream_version}.tar.gz
# Petr Pisar's public key (4B528393E6A3B0DFB2EF3A6412C9C5C767C6FAA2)
Source1:        ppisar2011.pub
# Fix building on Perl without "." in @INC, CPAN RT#121760
Patch0:         Test-Signature-1.11-Fix-building-on-Perl-without-.-in-INC.patch 
# Required to pass tests after patching
Patch1:         Test-Signature-1.11-Resign-patched-code.patch
BuildArch:      noarch
# Module Build
BuildRequires:  gnupg2
BuildRequires:  perl
BuildRequires:  perl(Config)
BuildRequires:  perl(Cwd)
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(ExtUtils::Manifest)
BuildRequires:  perl(Fcntl)
BuildRequires:  perl(File::Find)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(FindBin)
# Module Runtime
BuildRequires:  perl(Exporter)
BuildRequires:  perl(Module::Signature)
BuildRequires:  perl(Socket)
BuildRequires:  perl(strict)
BuildRequires:  perl(Test::Builder)
BuildRequires:  perl(vars)
# Test Suite
BuildRequires:  perl(Test::More)
# Optional Tests
BuildRequires:  perl(File::Find::Rule)
BuildRequires:  perl(Test::Pod) >= 0.95
# Runtime
# Package just skips (or, optionally, fails) testing if Module::Signature not installed
Requires:       perl(Module::Signature)
# Likewise, needs Socket to connect to keyserver
Requires:       perl(Socket)

%description
Module::Signature allows you to verify that a distribution has not been
tampered with. Test::Signature lets that be tested as part of the
distribution's test suite.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%patch -P 0 -p1
%patch -P 1 -p1

# Create a GPG directory for testing, to avoid using ~/.gnupg
export GNUPGHOME=%{gnupghome}

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
gpg2 --import %{SOURCE1}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}%{perl_vendorlib}

%files
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Signature.3*


%changelog
* Thu Jan 30 2025 pterjan <pterjan> 1.110.0-10.mga10
+ Revision: 2143638
- Rebuild for patchN deprecation

* Wed Mar 30 2022 umeabot <umeabot> 1.110.0-9.mga9
+ Revision: 1833996
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.110.0-8.mga8
+ Revision: 1506540
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.110.0-7.mga7
+ Revision: 1286810
- Mageia 7 Mass Rebuild

* Tue Oct 03 2017 tv <tv> 1.110.0-6.mga7
+ Revision: 1166913
- rebuild with fixed rpm for missing autodeps

* Fri Sep 15 2017 tv <tv> 1.110.0-5.mga7
+ Revision: 1154112
- BR gnupg2 instead of gnupg
- Fix building on Perl without "." in @INC (CPAN RT#121760)

* Sun Jun 19 2016 pterjan <pterjan> 1.110.0-3.mga6
+ Revision: 1034643
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 1.110.0-2.mga6
+ Revision: 1002313
- Made the spec file more standard

* Thu Mar 24 2016 tv <tv> 1.11-1.mga6
+ Revision: 995051
- imported package perl-Test-Signature


* Thu Mar 24 2016 Thierry Vignaud <tv@mageia.org> 1.11-1.mga6
- import from FC
